@@ -8,17 +8,15 @@ import logging
 import uuid
 
 from dcyd.utils.async_logger import async_logger
-from dcyd.utils.async_publisher import async_publisher
 import dcyd.utils.constants as constants
 from dcyd.utils.utils import (
+    get_gcp_project_id,
     get_project_id,
-    get_account_data,
     get_mpm_client_data,
     make_json_serializable
 )
 
 logger = async_logger()
-publisher = async_publisher()
 
 def mpm(func=None, **custom_kwargs):
     '''Decorator factory
@@ -42,7 +40,6 @@ def mpm(func=None, **custom_kwargs):
             payload = format_payload(
                 func, args, kwargs, custom_kwargs, req_ts, response
             )
-            send_payload(payload)
             logger.info(constants.MPM_LOG_MSG, payload)
 
             # Send expected response to function caller.
@@ -56,13 +53,6 @@ def mpm(func=None, **custom_kwargs):
     return decorator
 
 
-def send_payload(payload):
-    publisher.publish(
-        publisher.topic_path(get_project_id(), constants.MPM_PUBSUB_TOPIC),
-        data=json.dumps(payload).encode('utf-8')
-    )
-
-
 def format_payload(
         func, func_args, func_kwargs, custom_kwargs, req_ts, response
 ):
@@ -112,7 +102,7 @@ def format_payload(
             'request_response': make_json_serializable(response),
             'request_response_timestamp': dt.datetime.utcnow().isoformat()
         },
-        'account': get_account_data(),
+        'project_id': get_project_id(),
         'mpm_client': get_mpm_client_data(),
         'custom_data': make_json_serializable(custom_kwargs),
     }
